@@ -1,4 +1,5 @@
 import logging
+import subprocess
 from subprocess import PIPE, Popen
 from threading import Lock
 from typing import List, Optional, Union
@@ -35,7 +36,7 @@ class Jumanpp(Processor):
         senter: Optional[Processor] = None,
     ) -> None:
         self.executable = executable  #: Juman++ のパス．
-        self.options = options  #: Juman++ のオプション．
+        self.options: List[str] = options or []  #: Juman++ のオプション．
         self.senter = senter
         self._proc: Optional[Popen] = None
         try:
@@ -46,12 +47,16 @@ class Jumanpp(Processor):
 
     def __repr__(self) -> str:
         arg_string = f"executable={repr(self.executable)}"
-        if self.options is not None:
+        if self.options:
             arg_string += f", options={repr(self.options)}"
         if self.senter is not None:
             arg_string += f", senter={repr(self.senter)}"
         return f"{self.__class__.__name__}({arg_string})"
 
+    def __del__(self) -> None:
+        if self._proc is not None:
+            self._proc.kill()
+
     def is_available(self) -> bool:
         """Jumanpp が利用可能であれば True を返す．"""
         return self._proc is not None and self._proc.poll() is None
@@ -120,10 +125,19 @@ class Jumanpp(Processor):
                     break
             return Sentence.from_jumanpp(jumanpp_text)
 
+    def get_version(self) -> str:
+        """Juman++ のバージョンを返す．"""
+        if not self.is_available():
+            raise RuntimeError("Juman++ is not available.")
+        p = subprocess.run(self.version_command, capture_output=True, encoding="utf-8")
+        return p.stdout.strip()
+
     @property
     def run_command(self) -> List[str]:
         """解析時に実行するコマンド．"""
-        command = [self.executable]
-        if self.options:
-            command += self.options
-        return command
+        return [self.executable] + self.options
+
+    @property
+    def version_command(self) -> List[str]:
+        """バージョンを確認するコマンド．"""
+        return [self.executable, "--version"]
