@@ -1,4 +1,5 @@
 import logging
+import subprocess
 from subprocess import PIPE, Popen
 from threading import Lock
 from typing import List, Optional, Union
@@ -39,7 +40,9 @@ class KNP(Processor):
         jumanpp: Optional[Processor] = None,
     ) -> None:
         self.executable = executable  #: KNP のパス．
-        self.options = options  #: KNP のオプション．
+        self.options = options or ["-tab"]  #: KNP のオプション．
+        if "-tab" not in self.options:
+            raise ValueError("`-tab` option is required when you use KNP. ")
         self.senter = senter
         self.jumanpp = jumanpp
         self._proc: Optional[Popen] = None
@@ -51,7 +54,7 @@ class KNP(Processor):
 
     def __repr__(self) -> str:
         arg_string = f"executable={repr(self.executable)}"
-        if self.options is not None:
+        if self.options:
             arg_string += f", options={repr(self.options)}"
         if self.senter is not None:
             arg_string += f", senter={repr(self.senter)}"
@@ -59,6 +62,10 @@ class KNP(Processor):
             arg_string += f", jumanpp={repr(self.jumanpp)}"
         return f"{self.__class__.__name__}({arg_string})"
 
+    def __del__(self) -> None:
+        if self._proc is not None:
+            self._proc.kill()
+
     def is_available(self) -> bool:
         """KNP が利用可能であれば True を返す．"""
         return self._proc is not None and self._proc.poll() is None
@@ -149,12 +156,19 @@ class KNP(Processor):
                     break
             return Sentence.from_knp(knp_text)
 
+    def get_version(self) -> str:
+        """Juman++ のバージョンを返す．"""
+        if not self.is_available():
+            raise RuntimeError("KNP is not available.")
+        p = subprocess.run(self.version_command, capture_output=True, encoding="utf-8")
+        return p.stderr.strip()
+
     @property
     def run_command(self) -> List[str]:
         """解析時に実行するコマンド．"""
-        command = [self.executable]
-        if self.options:
-            command += self.options
-        else:
-            command += ["-tab"]
-        return command
+        return [self.executable] + self.options
+
+    @property
+    def version_command(self) -> List[str]:
+        """バージョンを確認するコマンド．"""
+        return [self.executable, "-v"]
