@@ -1,7 +1,6 @@
 import logging
 from typing import Any, List, Optional, Sequence, Union
 
-from rhoknp.cohesion.coreference import EntityManager
 from rhoknp.cohesion.pas import Pas
 from rhoknp.props.named_entity import NamedEntity
 from rhoknp.units.base_phrase import BasePhrase
@@ -39,33 +38,24 @@ class Document(Unit):
         self.index = self.count
         Document.count += 1
 
-        self._doc_id: Optional[str] = None
-
-        self.entity_manager = EntityManager()
+        self.doc_id: str = ""  #: 文書 ID．
 
     def __post_init__(self) -> None:
         super().__post_init__()
 
         # Set doc_id.
         if self.need_senter is False and len(self.sentences) > 0:
-            doc_ids = []
-            for sentence in self.sentences:
-                doc_id: Optional[str] = None
-                try:
-                    doc_id = sentence.doc_id
-                except AttributeError:
-                    pass
-                doc_ids.append(doc_id)
-            self._doc_id = doc_ids[0]
-            if not all(doc_id == self._doc_id for doc_id in doc_ids):
+            doc_ids = [sentence.doc_id for sentence in self.sentences]
+            self.doc_id = doc_ids[0]
+            if not all(doc_id == self.doc_id for doc_id in doc_ids):
                 logger.warning(
-                    f"'doc_id' is not consistent; use 'doc_id' extracted from the first sentence: {self._doc_id}."
+                    f"'doc_id' is not consistent; use 'doc_id' extracted from the first sentence: {self.doc_id}."
                 )
 
     def __eq__(self, other: Any) -> bool:
         if isinstance(other, Document) is False:
             return False
-        return self._doc_id == other._doc_id and self.text == other.text
+        return self.doc_id == other.doc_id and self.text == other.text
 
     @property
     def parent_unit(self) -> None:
@@ -77,33 +67,9 @@ class Document(Unit):
         """下位の言語単位（文）のリスト．解析結果にアクセスできないなら None．"""
         return self._sentences
 
-    @property
-    def doc_id(self) -> str:
-        """文書 ID．
-
-        Raises:
-            AttributeError: 文書 IDにアクセスできない場合．
-        """
-        if self._doc_id is None:
-            raise AttributeError("document id has not been set")
-        return self._doc_id
-
-    @doc_id.setter
-    def doc_id(self, doc_id: str) -> None:
-        """文書 ID．
-
-        Args:
-            doc_id: 文書 ID．
-        """
-        self._doc_id = doc_id
-
     @property
     def did(self) -> str:
-        """文書 ID（doc_id のエイリアス）．
-
-        Raises:
-            AttributeError: 文書 IDにアクセスできない場合．
-        """
+        """文書 ID（doc_id のエイリアス）．"""
         return self.doc_id
 
     @did.setter
@@ -184,12 +150,12 @@ class Document(Unit):
 
     @property
     def pas_list(self) -> List[Pas]:
-        """述語項構造のリストを返却．
+        """述語項構造のリスト．
 
         Raises:
             AttributeError: 解析結果にアクセスできない場合．
         """
-        return [base_phrase.pas for base_phrase in self.base_phrases if base_phrase.pas is not None]
+        return [pas for sentence in self.sentences for pas in sentence.pas_list]
 
     @property
     def need_senter(self) -> bool:
