@@ -22,7 +22,7 @@ class Morpheme(Unit):
     """形態素クラス．"""
 
     _ATTRIBUTES = (
-        "surf",
+        "_surf",
         "reading",
         "lemma",
         "pos",
@@ -55,6 +55,9 @@ class Morpheme(Unit):
         + rf"( {FeatureDict.PAT.pattern})?$"
     )
 
+    _ESCAPE_MAP = {" ": "　", '"': "”"}
+    _UNESCAPE_MAP = {v: k for k, v in _ESCAPE_MAP.items()}
+
     count = 0
 
     def __init__(
@@ -76,6 +79,7 @@ class Morpheme(Unit):
     ) -> None:
         super().__init__()
         self.text = text
+        self._text_escaped = text
         self.reading = reading  #: 読み．
         self.lemma = lemma  #: 原形．
         self.pos = pos  #: 品詞．
@@ -99,6 +103,10 @@ class Morpheme(Unit):
         if homograph is False:
             Morpheme.count += 1
 
+        # Resume text if it is escaped
+        if self.semantics.get("元半角") is True:
+            self.text = self._UNESCAPE_MAP.get(self.text, self.text)
+
     def __eq__(self, other: Any) -> bool:
         if isinstance(other, type(self)) is False:
             return False
@@ -109,6 +117,8 @@ class Morpheme(Unit):
     @cached_property
     def global_index(self) -> int:
         """文書全体におけるインデックス．"""
+        if self.sentence.has_document is False:
+            return self.index
         if self.index > 0:
             return self.sentence.morphemes[self.index - 1].global_index + 1
         if self.sentence.index == 0:
@@ -199,6 +209,11 @@ class Morpheme(Unit):
         """表層表現．"""
         return self.text
 
+    @property
+    def _surf(self) -> str:
+        """表層表現（Juman/KNP フォーマット出力用）．"""
+        return self._text_escaped
+
     @property
     def canon(self) -> Optional[str]:
         """代表表記．"""
